summaryrefslogtreecommitdiff
path: root/include/media-thumbnail-private.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/media-thumbnail-private.h')
-rwxr-xr-xinclude/media-thumbnail-private.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/media-thumbnail-private.h b/include/media-thumbnail-private.h
index a7d1daf..84842f6 100755
--- a/include/media-thumbnail-private.h
+++ b/include/media-thumbnail-private.h
@@ -33,7 +33,7 @@ extern "C" {
* This function generates a hash code using its original path by md5 algorithm.
* If done, the code will be returned.
*
* @return This function returns zero(MEDIA_THUMB_ERROR_NONE) on success, or negative value with error code.
* Please refer 'media-thumb-error.h' to know the exact meaning of the error.
* @param[in] origin_path The path of the original media
* @param[out] hash_code The hash code generated by md5 algorithm.
@@ -49,7 +49,7 @@ extern "C" {
void gen_thumb_hash_code()
{
- int ret = MEDIA_THUMB_ERROR_NONE;
+ int ret = MS_MEDIA_ERR_NONE;
const char *origin_path = "/opt/usr/media/test.jpg";
char hashcode[255];
@@ -33,7 +33,7 @@ extern "C" {
* If done, the code will be returned.
*
- * @return This function returns zero(MEDIA_THUMB_ERROR_NONE) on success, or negative value with error code.
+ * @return This function returns zero(MS_MEDIA_ERR_NONE) on success, or negative value with error code.
* Please refer 'media-thumb-error.h' to know the exact meaning of the error.
* @param[in] origin_path The path of the original media